@@ -1,8 +1,10 @@
 from typing import List
-from .item_result import Item
-from ..sdk.models import SearchResult
 
-class SearchResult(SearchResult):
+from ..sdk import models as sdk_models
+from .item_result import Item
+
+
+class SearchResult(sdk_models.SearchResult):
     items: List[Item]
     total_result_count: int
     search_url: str
